blob

package
v0.0.0-...-c675715 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 27, 2018 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type HybridRawGzipBlob

type HybridRawGzipBlob struct {
	Raw     func() []byte
	Gzipped func() []byte
}

HybridRawGzipBlob is an hybrid blob that can gives its content in raw or gzipped form

func NewGzippedBlob

func NewGzippedBlob(gzipped []byte) HybridRawGzipBlob

NewGzippedBlob returns a new hybrid blob from a gzipped form

func NewRawBlob

func NewRawBlob(raw []byte) HybridRawGzipBlob

NewRawBlob returns a new hybrid blob from a raw form

Jump to