common

package
v0.0.0-...-c675715 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 27, 2018 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ProgramInfo = ProgramInfoStruct{"GSSP",
	"Go Google Site Proxy",
	"0.0.1-SNAPSHOT",
	"undefined",
	"undefined",
	"https://ggsp.fever.ch"}

ProgramInfo is a variable containing the informations about the current build

Functions

This section is empty.

Types

type LazyContainer

type LazyContainer struct {
	// Get returns the value generated by the function (computes it if needed)
	Get func() unsafe.Pointer
}

LazyContainer is a lazy datastructure that allows a single evaluation of a given function

func NewLazyContainer

func NewLazyContainer(f func() unsafe.Pointer) *LazyContainer

NewLazyContainer returns a LazyContainer that will contain the result of the given fonction

type ProgramInfoStruct

type ProgramInfoStruct struct {
	Name       string
	Fullname   string
	Version    string
	Git        string
	BuildDate  string
	ProjectURL string
}

ProgramInfoStruct is a structure that define the program (incl. build informations)

Directories

Path Synopsis

Jump to