utils

package
v0.0.0-...-c675715 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 27, 2018 License: GPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

const MaxInt = int(MaxUint >> 1)

MaxInt is the maximum signed int

const MaxInt16 = int16(MaxUint16 >> 1)

MaxInt16 is the maximum signed int16

const MaxInt32 = int32(MaxUint32 >> 1)

MaxInt32 is the maximum signed int32

const MaxInt64 = int64(MaxUint64 >> 1)

MaxInt64 is the maximum signed int64

const MaxUint = ^uint(0)

MaxUint is the maximum unsigned int

const MaxUint16 = ^uint16(0)

MaxUint16 is the maximum unsigned int16

const MaxUint32 = ^uint32(0)

MaxUint32 is the maximum unsigned int32

const MaxUint64 = ^uint64(0)

MaxUint64 is the maximum unsigned int64

const MinInt = -MaxInt - 1

MinInt is the minimum signed int

const MinInt16 = -MaxInt16 - 1

MinInt16 is the minimum signed int16

const MinInt32 = -MaxInt32 - 1

MinInt32 is the minimum signed int32

const MinInt64 = -MaxInt64 - 1

MinInt64 is the minimum signed int64

const MinUint = 0

MinUint is the minimum unsigned int

const MinUint16 = 0

MinUint16 is the minimum unsigned int16

const MinUint32 = 0

MinUint32 is the minimum unsigned int32

const MinUint64 = 0

MinUint64 is the minimum unsigned int64

Variables

This section is empty.

Functions

func Epoch

func Epoch() int64

Epoch returns t as a Unix time, the number of seconds elapsed since January 1, 1970 UTC.

func EpochNano

func EpochNano() int64

EpochNano returns t as a Unix time, the number of nanoseconds elapsed since January 1, 1970 UTC.

Types

This section is empty.

Jump to