Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ProgramInfo = ProgramInfoStruct{"GSSP",
"Go Google Site Proxy",
"0.0.1-SNAPSHOT",
"undefined",
"undefined",
"https://ggsp.fever.ch"}
ProgramInfo is a variable containing the informations about the current build
Functions ¶
This section is empty.
Types ¶
type LazyContainer ¶
type LazyContainer struct {
// Get returns the value generated by the function (computes it if needed)
Get func() unsafe.Pointer
}
LazyContainer is a lazy datastructure that allows a single evaluation of a given function
func NewLazyContainer ¶
func NewLazyContainer(f func() unsafe.Pointer) *LazyContainer
NewLazyContainer returns a LazyContainer that will contain the result of the given fonction
Click to show internal directories.
Click to hide internal directories.